==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/IntOrStringBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IntOrStringBuilder extends IntOrStringFluentImpl<IntOrStringBuilder> implements VisitableBuilder<IntOrString,IntOrStringBuilder>{
  public IntOrStringBuilder() {
    this(false);
  }
  public IntOrStringBuilder(Boolean validationEnabled) {
    this(new IntOrString(), validationEnabled);
  }
  public IntOrStringBuilder(IntOrStringFluent<?> fluent) {
    this(fluent, false);
  }
  public IntOrStringBuilder(IntOrStringFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new IntOrString(), validationEnabled);
  }
  public IntOrStringBuilder(IntOrStringFluent<?> fluent,IntOrString instance) {
    this(fluent, instance, false);
  }
  public IntOrStringBuilder(IntOrStringFluent<?> fluent,IntOrString instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withValue(instance.getValue());
    }
    this.validationEnabled = validationEnabled; 
  }
  public IntOrStringBuilder(IntOrString instance) {
    this(instance,false);
  }
  public IntOrStringBuilder(IntOrString instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withValue(instance.getValue());
    }
    this.validationEnabled = validationEnabled; 
  }
  IntOrStringFluent<?> fluent;
  Boolean validationEnabled;
  public IntOrString build() {
    IntOrString buildable = new IntOrString(fluent.getValue());
    return buildable;
  }
  
}

==> kubernetes-model-core-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/IntOrStringBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class IntOrStringBuilder extends IntOrStringFluent<IntOrStringBuilder> implements VisitableBuilder<IntOrString,IntOrStringBuilder>{
  public IntOrStringBuilder() {
    this(false);
  }
  public IntOrStringBuilder(Boolean validationEnabled) {
    this(new IntOrString(), validationEnabled);
  }
  public IntOrStringBuilder(IntOrStringFluent<?> fluent) {
    this(fluent, false);
  }
  public IntOrStringBuilder(IntOrStringFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new IntOrString(), validationEnabled);
  }
  public IntOrStringBuilder(IntOrStringFluent<?> fluent,IntOrString instance) {
    this(fluent, instance, false);
  }
  public IntOrStringBuilder(IntOrStringFluent<?> fluent,IntOrString instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new IntOrString());

    if (instance != null) {
      fluent.withValue(instance.getValue());
      fluent.withValue(instance.getValue());
    }
    this.validationEnabled = validationEnabled; 
  }
  public IntOrStringBuilder(IntOrString instance) {
    this(instance,false);
  }
  public IntOrStringBuilder(IntOrString instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new IntOrString());

    if (instance != null) {
      this.withValue(instance.getValue());
      this.withValue(instance.getValue());
    }
    this.validationEnabled = validationEnabled; 
  }
  IntOrStringFluent<?> fluent;
  Boolean validationEnabled;
  public IntOrString build() {
    IntOrString buildable = new IntOrString(fluent.getValue());
    return buildable;
  }
  
}
